import React, { Component } from 'react';
import './rangeSlider.css';

class RangeSlider extends Component {
  constructor(props) {
    super(props);

    this.state = {
      minVal: this.props.min,
      maxVal: this.props.max,
    };

    this.minValRef = React.createRef();
    this.maxValRef = React.createRef();
    this.rangeRef = React.createRef();
    this.edgeVal = this.props.stepVal ? this.props.stepVal : 1;
  }

  getPercent(value) {
    return Math.round(
      ((value - this.props.min) / (this.props.max - this.props.min)) * 100
    );
  }

  updateRange() {
    const minPercent = this.getPercent(this.minValRef.current);
    const maxPercent = this.getPercent(this.maxValRef.current);

    if (this.rangeRef.current) {
      this.rangeRef.current.style.left = `${minPercent}%`;
      this.rangeRef.current.style.width = `${maxPercent - minPercent}%`;
    //   console.log("width",this.rangeRef.current.style.width)
    }
  }

  handleMinChange = (event) => {
    const value = Math.min(
      Number(event.target.value),
      this.state.maxVal - this.edgeVal
    );
    this.setState({ minVal: value });
    this.minValRef.current = value;
    this.updateRange();
  };

  handleMaxChange = (event) => {
    const value = Math.max(
      Number(event.target.value),
      this.state.minVal + this.edgeVal
    );
    this.setState({ maxVal: value });
    this.maxValRef.current = value;
    this.updateRange();
  };

  componentDidMount() {
    this.updateRange();
    this.props.onChange({ min: this.state.minVal, max: this.state.maxVal });
    this.rangeRef.current.style.width = '100%';
    this.maxValRef.current =  this.state.maxVal;
  }

  componentDidUpdate() {
    this.props.onChange({ min: this.state.minVal, max: this.state.maxVal });
  }

  render() {
    return (
      <div className="container">
        <input
          type="range"
          min={this.props.min}
          max={this.props.max}
          value={this.state.minVal}
          step={this.props.stepVal}
          onChange={this.handleMinChange}
          className="thumb thumb--left"
          style={{ zIndex: this.state.minVal > this.props.max - 100 && '5' }}
        />
        <input
          type="range"
          min={this.props.min}
          max={this.props.max}
          step={this.props.stepVal}
          value={this.state.maxVal}
          onChange={this.handleMaxChange}
          className="thumb thumb--right"
        />

        <div className="slider">
          <div className="slider__track" />
          <div ref={this.rangeRef} className="slider__range" />
          <div className="slider__left-value">{this.state.minVal}</div>
          <div className="slider__right-value">{this.state.maxVal}</div>
        </div>
      </div>
    );
  }
}

export default RangeSlider;
